@@ -6,4 +6,10 @@ from .getcourse_by_date import GCbyDate
 from .ym_by_date import YMbyDate
 from .btrx_by_date import BTRXbyDate
 from .vk_by_date import VKbyDate
-from .alfacrm_by_date import ALFAbyDate
\ No newline at end of file
+try:
+    from .alfacrm_by_date import ALFAbyDate
+    from .yandex_disk_by_page import DISKbyPage
+    from .ozon_an_by_date import OZONANbyDate
+    from .mskld_by_date import MSKLDbyDate
+except:
+    pass
\ No newline at end of file
